spec_plots
==========

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

.. image:: https://badge.fury.io/py/spec_plots.svg
    :target: https://badge.fury.io/py/spec_plots
    :alt: PyPi Status

.. image:: https://readthedocs.org/projects/spec-plots/badge/?version=latest
    :target: https://spec-plots.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://github.com/spacetelescope/spec_plots/workflows/CI/badge.svg
    :target: https://github.com/spacetelescope/spec_plots/actions
    :alt: CI Status

.. image:: https://codecov.io/gh/spacetelescope/spec_plots/branch/main/graph/badge.svg
  :target: https://codecov.io/gh/spacetelescope/spec_plots
  :alt: Codecov

Generates spectroscopic preview plots for MAST missions.  Full documentation available at [Read the Docs](https://readthedocs.org/projects/spec-plots/).
